@@ -1,6 +1,6 @@
 package Gearman::Client;
 use version ();
-$Gearman::Client::VERSION = version->declare("2.004.002");
+$Gearman::Client::VERSION = version->declare("2.004.003");
 
 use strict;
 use warnings;
@@ -16,12 +16,13 @@ Gearman::Client - Client for gearman distributed job system
     $client->job_servers(
       '127.0.0.1',
       {
-        cert_file  => ...,
         host      => '10.0.0.1',
-        key_file   => ...,
-        port      => 4733,
+        port      => 4730,
         socket_cb => sub {...},
         use_ssl   => 1,
+        ca_file   => ...,
+        cert_file => ...,
+        key_file  => ...,
       }
     );
 
@@ -44,11 +45,13 @@ Gearman::Client - Client for gearman distributed job system
 
 I<Gearman::Client> is a client class for the Gearman distributed job
 system, providing a framework for sending jobs to one or more Gearman
-servers.  These jobs are then distributed out to a farm of workers.
+servers. These jobs are then distributed out to a farm of workers.
 
 Callers instantiate a I<Gearman::Client> object and from it dispatch
 single tasks, sets of tasks, or check on the status of tasks.
 
+I<Gearman::Client> is derived from L<Gearman::Objects>
+
 =head1 USAGE
 
 =head2 Gearman::Client->new(%options)
@@ -62,8 +65,10 @@ settings in I<%options>, which can contain:
 
 =item * job_servers
 
-Calls I<job_servers> (see below) to initialize the list of job
-servers.  Value in this case should be an arrayref.
+List of job servers. Value should be an array reference, hash reference
+or scalar.
+
+Calls L<Gearman::Objects> to set I<job_servers>
 
 =item * prefix
 
@@ -94,12 +99,6 @@ Returns a scalar reference to the result, or undef on failure.
 If you provide on_complete and on_fail handlers, they're ignored, as
 this function currently overrides them.
 
-=head2 $client-E<gt>dispatch_background($task)
-
-=head2 $client-E<gt>dispatch_background($funcname, $arg, \%options)
-
-Dispatches a task and doesn't wait for the result. Return value
-is an opaque scalar that can be used to refer to the task with get_status.
 
 =head2 $taskset = $client-E<gt>new_task_set
 
@@ -394,13 +393,18 @@ sub do_task {
     return $ret;
 } ## end sub do_task
 
-=head2 dispatch_background($func, $arg_p, $opts)
+=head2 dispatch_background($func, $arg_p, $options_hr)
 
 =head2 dispatch_background($task)
 
-dispatches job in background
+Dispatches a C<task> and doesn't wait for the result. Return value
+is an opaque scalar that can be used to refer to the task with L<get_status>.
 
-return the handle from the jobserver, or undef on failure
+B<It is strongly recommended to set> L<Gearman::Task> C<uniq> B<option>
+to insure gearmand does not squash jobs if it store background jobs in a persistence backend.
+See the issue L<#87|https://github.com/gearman/gearmand/issues/87#issuecomment-291119785>
+
+B<return> the handle from the jobserver, or undef on failure
 
 =cut
 
@@ -453,8 +457,8 @@ sub add_hook {
 =head2 get_status($handle)
 
 The Gearman Server will assign a scalar job handle when you request a 
-background job with dispatch_background. Save this scalar, and use it later in 
-order to request the status of this job. 
+background job with L<dispatch_background>. Save this scalar, and use it later
+in order to request the status of this job.
 
 B<return> L<Gearman::JobStatus> on success
 
