@@ -1,6 +1,6 @@
 package Gearman::Objects;
 use version ();
-$Gearman::Objects::VERSION = version->declare("2.004.002");
+$Gearman::Objects::VERSION = version->declare("2.004.003");
 
 use strict;
 use warnings;
@@ -53,11 +53,12 @@ sub new {
     return $self;
 } ## end sub new
 
-=head2 job_servers([$js])
+=head2 job_servers([$job_servers])
 
-getter/setter
+Initialize the list of job servers.
+C<$job_servers>should be an array reference, hash reference or scalar.
 
-C<$js> array reference, hash reference or scalar
+B<return> C<[job_servers]>
 
 =cut
 
@@ -70,7 +71,7 @@ sub job_servers {
 
 =head2 set_job_servers($js)
 
-set job_servers attribute by canonicalized C<$js>_
+set job_servers attribute by canonicalized C<$js>
 
 =cut
 
@@ -88,7 +89,7 @@ C<$js> a string, hash reference or array reference of aforementioned.
 
 Hash reference should contain at least host key.
 
-All keys: host, port (4730 on default), use_ssl, key_file, cert_file,
+All keys: host, port (4730 on default), use_ssl, ca_file, cert_file, key_file,
 socket_cb
 
 B<return> [canonicalized list]
@@ -207,7 +208,7 @@ sub socket {
     my $sc = "IO::Socket::IP";
     if ($js->{use_ssl}) {
         $sc = "IO::Socket::SSL";
-        for (qw/ key_file cert_file /) {
+        for (qw/ ca_file cert_file key_file /) {
             $js->{$_} || next;
             $opts{ join('_', "SSL", $_) } = $js->{$_};
         }
