@@ -1,14 +1,13 @@
 package Gearman::Taskset;
 use version ();
-$Gearman::Taskset::VERSION = version->declare("2.004.002");
-
+$Gearman::Taskset::VERSION = version->declare("2.004.003");
 
 use strict;
 use warnings;
 
 =head1 NAME
 
-Gearman::Taskset - a taskset in Gearman, from the point of view of a client
+Gearman::Taskset - a taskset in Gearman, from the point of view of a L<Gearman::Client>
 
 =head1 SYNOPSIS
 
@@ -23,42 +22,29 @@ Gearman::Taskset - a taskset in Gearman, from the point of view of a client
 
 =head1 DESCRIPTION
 
-Gearman::Taskset is a Gearman::Client's representation of tasks queue t in Gearman
+Gearman::Taskset is a L<Gearman::Client>'s representation of tasks queue
 
 =head1 METHODS
 
 =cut
 
 use fields (
-
-    # { handle => [Task, ...] }
-    'waiting',
-
-    # Gearman::Client
-    'client',
-
-    # arrayref
-    'need_handle',
-
-    # default socket (non-merged requests)
-    'default_sock',
-
-    # default socket's ip/port
-    'default_sockaddr',
-
-    # { hostport => socket }
-    'loaned_sock',
-
-    # bool, if taskset has been cancelled mid-processing
-    'cancelled',
-
-    # hookname -> coderef
-    'hooks',
+    qw/
+        waiting
+        client
+        need_handle
+        default_sock
+        default_sockaddr
+        loaned_sock
+        cancelled
+        hooks
+        /
 );
 
 use Carp          ();
 use Gearman::Util ();
 use Gearman::ResponseParser::Taskset;
+use IO::Select;
 
 # i thought about weakening taskset's client, but might be too weak.
 use Scalar::Util ();
@@ -80,12 +66,25 @@ sub new {
         $self = fields::new($self);
     }
 
+    # { handle => [Task, ...] }
     $self->{waiting}     = {};
     $self->{need_handle} = [];
     $self->{client}      = $client;
+
+    # { hostport => socket }
     $self->{loaned_sock} = {};
-    $self->{cancelled}   = 0;
-    $self->{hooks}       = {};
+
+    # bool, if taskset has been cancelled mid-processing
+    $self->{cancelled} = 0;
+
+    # { hookname => coderef }
+    $self->{hooks} = {};
+
+    # default socket (non-merged requests)
+    $self->{default_sock} = undef;
+
+    # $self->client()->_js_str($self->{default_sock});
+    $self->{default_sockaddr} = undef;
 
     return $self;
 } ## end sub new
@@ -94,7 +93,7 @@ sub DESTROY {
     my $self = shift;
 
     # During global cleanup this may be called out of order, and the client my not exist in the taskset.
-    return unless $self->{client};
+    return unless $self->client;
 
     if ($self->{default_sock}) {
         $self->client->_sock_cache($self->{default_sockaddr},
@@ -141,15 +140,17 @@ sub add_hook {
 
 =head2 client ()
 
-this method is part of the "Taskset" interface, also implemented by
-Gearman::Client::Async, where no tasksets make sense, so instead the
-Gearman::Client::Async object itself is also its taskset.  (the
-client tracks all tasks).  so don't change this, without being aware
-of Gearman::Client::Async.  similarly, don't access $ts->{client} without
-going via this accessor.
+B<return> L<Gearman::Client>
 
 =cut
 
+# this method is part of the "Taskset" interface, also implemented by
+# Gearman::Client::Async, where no tasksets make sense, so instead the
+# Gearman::Client::Async object itself is also its taskset.  (the
+# client tracks all tasks).  so don't change this, without being aware
+# of Gearman::Client::Async.  similarly, don't access $ts->{client} without
+# going via this accessor.
+
 sub client {
     return shift->{client};
 }
@@ -174,9 +175,10 @@ sub cancel {
         $sock->close;
     }
 
-    $self->{waiting}     = {};
-    $self->{need_handle} = [];
     $self->{client}      = undef;
+    $self->{loaned_sock} = {};
+    $self->{need_handle} = [];
+    $self->{waiting}     = {};
 } ## end sub cancel
 
 #
@@ -216,41 +218,27 @@ sub wait {
         . " passed to Taskset->wait."
         if keys %opts;
 
-    my %parser;    # fd -> Gearman::ResponseParser object
+    # fd -> Gearman::ResponseParser object
+    my %parser;
 
-    my ($rin, $rout, $eout) = ('', '', '');
-    my %watching;
-
-    for my $sock ($self->{default_sock}, values %{ $self->{loaned_sock} }) {
-        next unless $sock;
-        if (my $fd = $sock->fileno) {
-            vec($rin, $fd, 1) = 1;
-            $watching{$fd} = $sock;
-        }
-    } ## end for my $sock ($self->{default_sock...})
+    my $io = IO::Select->new($self->{default_sock},
+        values %{ $self->{loaned_sock} });
 
     while (!$self->{cancelled} && keys %{ $self->{waiting} }) {
         my $time_left = $timeout ? $timeout - Time::HiRes::time() : 0.5;
-
-        # TODO drop the eout.
-        my $nfound = select($rout = $rin, undef, $eout = $rin, $time_left);
+        my $nfound = select($io->bits(), undef, undef, $time_left);
         if ($timeout && $time_left <= 0) {
             $self->cancel;
             return;
         }
         next if !$nfound;
-
-        foreach my $fd (keys %watching) {
-            next unless vec($rout, $fd, 1);
-
-            # TODO: deal with error vector
-            my $sock   = $watching{$fd};
+        foreach my $fd ($io->can_read()) {
             my $parser = $parser{$fd}
                 ||= Gearman::ResponseParser::Taskset->new(
-                source  => $sock,
+                source  => $fd,
                 taskset => $self
                 );
-            eval { $parser->parse_sock($sock); };
+            eval { $parser->parse_sock($fd); };
 
             if ($@) {
 
@@ -258,7 +246,7 @@ sub wait {
                 # We're not in an accessible place here, so if all job servers fail we must die to prevent hanging.
                 Carp::croak("Job server failure: $@");
             } ## end if ($@)
-        } ## end foreach my $fd (keys %watching)
+        } ## end foreach my $fd ($io->can_read...)
     } ## end while (!$self->{cancelled...})
 } ## end sub wait
 
@@ -292,7 +280,7 @@ sub add_task {
     while (@{ $self->{need_handle} }) {
         my $rv
             = $self->_wait_for_packet($jssock,
-            $self->{client}->{command_timeout});
+            $self->client()->{command_timeout});
         if (!$rv) {
 
             # ditch it, it failed.
@@ -320,7 +308,7 @@ sub _get_default_sock {
     my $getter = sub {
         my $js = shift;
         return $self->{loaned_sock}{$js}
-            || $self->{client}->_get_js_sock($js);
+            || $self->client()->_get_js_sock($js);
     };
 
     my ($js, $jss) = $self->client()->_get_random_js_sock($getter);
@@ -365,10 +353,8 @@ sub _get_hashed_sock {
 # otherwise, return value is undefined.
 sub _wait_for_packet {
     my ($self, $sock, $timeout) = @_;
-
-    #TODO check $err after read
-    my $err;
-    my $res = Gearman::Util::read_res_packet($sock, \$err, $timeout);
+    my $res = Gearman::Util::read_res_packet($sock, \my $err, $timeout);
+    $err && Carp::croak("reading response packet failed: $err");
 
     return $res ? $self->process_packet($res, $sock) : 0;
 } ## end sub _wait_for_packet
@@ -420,12 +406,12 @@ sub _fail_jshandle {
         or Carp::croak "_fail_jshandle() called without shandle parameter";
 
     my $task_list = $self->{waiting}{$shandle}
-        or Carp::croak "Uhhhh:  got $type for unknown handle: $shandle";
+        or Carp::croak "Got $type for unknown handle: $shandle";
 
     my $task = shift @{$task_list};
     (Scalar::Util::blessed($task) && $task->isa("Gearman::Task"))
         || Carp::croak
-        "Uhhhh:  task_list is empty on $type for handle $shandle\n";
+        "task_list is empty on $type for handle $shandle\n";
 
     $task->fail($msg || "jshandle fail");
 
@@ -452,7 +438,7 @@ sub process_packet {
             my ($blob) = shift;
             my $task = shift @{ $self->{need_handle} };
             $assert{task}
-                ->($task, "Um, got an unexpected job_created notification");
+                ->($task, "Got an unexpected job_created notification");
             my $shandle = $blob;
             my $ipport  = $self->_ip_port($sock);
 
@@ -478,7 +464,7 @@ sub process_packet {
             my $task      = shift @$task_list;
             $assert{task}->(
                 $task,
-                "Uhhhh:  task_list is empty on work_complete for handle $shandle"
+                "task_list is empty on work_complete for handle $shandle"
             );
 
             $task->complete(\$blob);
@@ -496,7 +482,7 @@ sub process_packet {
             my $task      = $task_list->[0];
             $assert{task}->(
                 $task,
-                "Uhhhh:  task_list is empty on work_data for handle $shandle"
+                "task_list is empty on work_data for handle $shandle"
             );
 
             $task->data(\$blob);
@@ -513,7 +499,7 @@ sub process_packet {
             my $task      = $task_list->[0];
             $assert{task}->(
                 $task,
-                "Uhhhh:  task_list is empty on work_warning for handle $shandle"
+                "task_list is empty on work_warning for handle $shandle"
             );
 
             $task->warning(\$blob);
@@ -531,7 +517,7 @@ sub process_packet {
             my $task      = $task_list->[0];
             $assert{task}->(
                 $task,
-                "Uhhhh:  task_list is empty on work_exception for handle $shandle"
+                "task_list is empty on work_exception for handle $shandle"
             );
 
             #FIXME we have to freeze $blob because Task->exception expected it in this form.
@@ -543,7 +529,7 @@ sub process_packet {
         work_fail => sub {
             my ($blob) = shift;
             my ($shandle, $msg) = split(/\0/, $blob);
-            $shandle ||=$blob;
+            $shandle ||= $blob;
             $self->_fail_jshandle($shandle, "work_fail", $msg);
             return 1;
         },
@@ -553,7 +539,7 @@ sub process_packet {
             my $task_list = $self->{waiting}{$shandle};
             ref($task_list) eq "ARRAY" && scalar(@{$task_list})
                 or Carp::croak
-                "Uhhhh:  got work_status for unknown handle: $shandle";
+                "Got work_status for unknown handle: $shandle";
 
             # FIXME: the server is (probably) sending a work_status packet for each
             # interested client, even if the clients are the same, so probably need
